@@ -14,12 +14,19 @@ const baseRule = {
     }
 }
 
+const predefinedVariables = {
+    "transpile_VERSION": transpile.VERSION
+}
+
 if (settings.DEBUG) {
     baseRule.exclude = /node_modules/
+    predefinedVariables.staticUrl = `(url => ${JSON.stringify(settings.STATIC_URL)} + url)`
+} else if (settings.STATICFILES_STORAGE !== "npm_mjs.storage.ManifestStaticFilesStorage") {
+    predefinedVariables.staticUrl = `(url => ${JSON.stringify(settings.STATIC_URL)} + url + "?v=" + ${transpile.VERSION})`
 }
 
 module.exports = { // eslint-disable-line no-undef
-    mode: settings.DEBUG ? 'development' : 'production',
+    mode: settings.DEBUG ? "development" : "production",
     module: {
         rules: [baseRule]
     },
@@ -29,9 +36,7 @@ module.exports = { // eslint-disable-line no-undef
         publicPath: transpile.BASE_URL
     },
     plugins: [
-        new webpack.DefinePlugin({
-            "transpile_VERSION": transpile.VERSION
-        })
+        new webpack.DefinePlugin(predefinedVariables)
     ],
     entry: transpile.ENTRIES
 }
