@@ -1,9 +1,12 @@
 import re
+from urllib.parse import quote
+from urllib.parse import urljoin
 
-from urllib.parse import quote, urljoin
 from django import template
-from django.templatetags.static import StaticNode, PrefixNode
 from django.apps import apps
+from django.contrib.staticfiles.storage import ManifestStaticFilesStorage
+from django.templatetags.static import PrefixNode
+from django.templatetags.static import StaticNode
 
 from npm_mjs.tools import get_last_run
 
@@ -17,10 +20,16 @@ class StaticTranspileNode(StaticNode):
         if apps.is_installed("django.contrib.staticfiles"):
             from django.contrib.staticfiles.storage import staticfiles_storage
 
-            return staticfiles_storage.url(path) + "?v=%s" % get_last_run("transpile")
+            if isinstance(staticfiles_storage, ManifestStaticFilesStorage):
+                return staticfiles_storage.url(path)
+            else:
+                return staticfiles_storage.url(path) + "?v=%s" % get_last_run(
+                    "transpile",
+                )
         else:
             return urljoin(
-                PrefixNode.handle_simple("STATIC_URL"), quote(path)
+                PrefixNode.handle_simple("STATIC_URL"),
+                quote(path),
             ) + "?v=%s" % get_last_run("transpile")
 
 
